
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
#
# To compare versions robustly, use `numpy.lib.NumpyVersion`
short_version = '1.15.2'
version = '1.15.2'
full_version = '1.15.2'
git_revision = '70f44796706be9dedf61907f69c975d2499411da'
release = True

if not release:
    version = full_version
